#

##

##

##

    	adventures
    		# adventures

    		# safes:mongo
    			# vaults
    			# lockers

    		# stack
    			# not unique

    		# organisms
    		# apps
    		# instruments

    	description

    		This is nodes that can be turned on and off.

    	objectives

    		adventures.map.py {
    			"adventures": [{
    				"name": "monetary",

    				"on": "mongod --dbpath ./../_mongo_data --port 39000",
    				"off": "mongod --shutdown --pidfilepath /var/run/mongodb/mongod.pid",

    				#
    				#	"on" or "off"
    				#
    				#
    				"status": "python3 monetary/_ops/status.py"
    			}]
    		}

    		adventures status

    			monetary: on
    			sanique: on
    			vv_turbo: on

    	vocab

    		node:
    			app:

    		on:

    		off: